==> webgen-0.95.tgz: webgen-0.95/procpic.php <==
<?php
/******oӰƵ{ΨഫWǤϧε 
       $str Oഫ A$preview =0oOwpA
       $target Mmؿ
       $preview =1NoOwA
***************************************************/
function procpic($str,$target,$preview)
{
 global $main_url, $upload_url;
  $target=trim($target);
  $tmp=$str;
  $str="";
  while (!(($pt=strpos($tmp,"<pic>"))===false))
    {
        $ok=substr($tmp,0,$pt);
        $str=$str.$ok;
	$pt1=strpos($tmp,"</pic>");
        if ($pt1==0)
        {
           echo "ʤ &lt;/pic&gt; <br>";
           return;
        }
	$picurl=substr($tmp,$pt+5,$pt1-$pt-5);
	$picurl=trim($picurl);
	//echo "picurl= $picurl<br>";
	if ($preview)
		{
		$str=$str."<img src=\"{$main_url}{$upload_url}{$target}/{$picurl}\">";
		}
	else
		{
		$str=$str."<img src=\"{$upload_url}{$target}/{$picurl}\">";
		}
	$tmp=substr($tmp,$pt1+6);
    }
    $str=$str.$tmp;
  $tmp=$str;
  $str="";
  while (!(($pt=strpos($tmp,"<picl>"))===false))
    {
        $ok=substr($tmp,0,$pt);
        $str=$str.$ok;
	$pt1=strpos($tmp,"</picl>");
        if ($pt1==0)
        {
           echo "ʤ &lt;/picl&gt; <br>";
           return;
        }
	$picurl=substr($tmp,$pt+6,$pt1-$pt-6);
	$picurl=trim($picurl);
	//echo "picurl= $picurl<br>";
	if ($preview)
		{
		$str=$str."<img src=\"{$main_url}{$upload_url}{$target}/{$picurl}\" align=\"left\">";
		}
	else
		{
		$str=$str."<img src=\"{$upload_url}{$target}/{$picurl}\" align=\"left\">";
		}
	$tmp=substr($tmp,$pt1+7);
    }
    $str=$str.$tmp;
  $tmp=$str;
  $str="";
  while (!(($pt=strpos($tmp,"<picr>"))===false))
    {
        $ok=substr($tmp,0,$pt);
        $str=$str.$ok;
	$pt1=strpos($tmp,"</picr>");
        if ($pt1==0)
        {
           echo "ʤ &lt;/picr&gt; <br>";
           return;
        }
	$picurl=substr($tmp,$pt+6,$pt1-$pt-6);
	$picurl=trim($picurl);
	//echo "picurl= $picurl<br>";
	if ($preview)
		{
		$str=$str."<img src=\"{$main_url}{$upload_url}{$target}/{$picurl}\" align=\"right\">";
		}
	else
		{
		$str=$str."<img src=\"{$upload_url}{$target}/{$picurl}\" align=\"right\">";
		}
	$tmp=substr($tmp,$pt1+7);
    }
    $str=$str.$tmp;
    return $str;
}
?>

==> webgen-0.98.tgz: webgen-0.98/procpic.php <==
<?php
/******oӰƵ{ΨഫWǤϧε 
       $str Oഫ A$preview =0oOwpA
       $target Mmؿ
       $preview =1NoOwA
***************************************************/
function procpic($str,$target,$preview)
{
 global $main_url, $upload_url,$img_url;
  if (!isset($img_url)) $img_url=$main_url;
  $target=trim($target);
  $tmp=$str;
  $str="";
  while (!(($pt=strpos($tmp,"<pic>"))===false))
    {
        $ok=substr($tmp,0,$pt);
        $str=$str.$ok;
	$pt1=strpos($tmp,"</pic>");
        if ($pt1==0)
        {
           echo "ʤ &lt;/pic&gt; <br>";
           return;
        }
	$picurl=substr($tmp,$pt+5,$pt1-$pt-5);
	$picurl=trim($picurl);
	//echo "picurl= $picurl<br>";
	if ($preview)
		{
		$str=$str."<img src=\"{$img_url}{$upload_url}{$target}/{$picurl}\">";
		}
	else
		{
		$str=$str."<img src=\"{$upload_url}{$target}/{$picurl}\">";
		}
	$tmp=substr($tmp,$pt1+6);
    }
    $str=$str.$tmp;
  $tmp=$str;
  $str="";
  while (!(($pt=strpos($tmp,"<picl>"))===false))
    {
        $ok=substr($tmp,0,$pt);
        $str=$str.$ok;
	$pt1=strpos($tmp,"</picl>");
        if ($pt1==0)
        {
           echo "ʤ &lt;/picl&gt; <br>";
           return;
        }
	$picurl=substr($tmp,$pt+6,$pt1-$pt-6);
	$picurl=trim($picurl);
	//echo "picurl= $picurl<br>";
	if ($preview)
		{
		$str=$str."<img src=\"{$img_url}{$upload_url}{$target}/{$picurl}\" align=\"left\">";
		}
	else
		{
		$str=$str."<img src=\"{$upload_url}{$target}/{$picurl}\" align=\"left\">";
		}
	$tmp=substr($tmp,$pt1+7);
    }
    $str=$str.$tmp;
  $tmp=$str;
  $str="";
  while (!(($pt=strpos($tmp,"<picr>"))===false))
    {
        $ok=substr($tmp,0,$pt);
        $str=$str.$ok;
	$pt1=strpos($tmp,"</picr>");
        if ($pt1==0)
        {
           echo "ʤ &lt;/picr&gt; <br>";
           return;
        }
	$picurl=substr($tmp,$pt+6,$pt1-$pt-6);
	$picurl=trim($picurl);
	//echo "picurl= $picurl<br>";
	if ($preview)
		{
		$str=$str."<img src=\"{$img_url}{$upload_url}{$target}/{$picurl}\" align=\"right\">";
		}
	else
		{
		$str=$str."<img src=\"{$upload_url}{$target}/{$picurl}\" align=\"right\">";
		}
	$tmp=substr($tmp,$pt1+7);
    }
    $str=$str.$tmp;
    return $str;
}
?>
